@@ -89,30 +89,10 @@ IEEE Trans. on Signal Processing, 46(2):497-501, February 1998.\n\
   }
 
   const int m = args(0).int_value(true);
-  if (error_state) {
-    err_wrong_type_arg ("cl2bp", args(0));
-    return retval;
-  }
   const double w1 = args(1).double_value();
-  if (error_state) {
-    err_wrong_type_arg ("cl2bp", args(1));
-    return retval;
-  }
   const double w2 = args(2).double_value();
-  if (error_state) {
-    err_wrong_type_arg ("cl2bp", args(2));
-    return retval;
-  }
   const ColumnVector up_vector(args(3).vector_value());
-  if (error_state) {
-    err_wrong_type_arg ("cl2bp", args(3));
-    return retval;
-  }
   const ColumnVector lo_vector(args(4).vector_value());
-  if (error_state) {
-    err_wrong_type_arg ("cl2bp", args(4));
-    return retval;
-  }
   if (up_vector.numel() != 3 || lo_vector.numel() != 3) {
     error("cl2bp: The up and lo vectors must contain 3 values");
     return retval;
@@ -126,10 +106,6 @@ IEEE Trans. on Signal Processing, 46(2):497-501, February 1998.\n\
   }
 
   const int L = args(5).int_value(true);
-  if (error_state) {
-    err_wrong_type_arg ("cl2bp", args(5));
-    return retval;
-  }
   if (L > 1000000) {
     error("cl2bp: The \"gridsize\" parameter cannot exceed 1000000");
     return retval;
